@@ -20,7 +20,7 @@ extensions = [
 ]
 
 templates_path = ["_templates"]
-exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store", "jupyter_execute"]
 
 language = "Python"
 
@@ -54,3 +54,4 @@ source_suffix = {
     ".md": "myst-nb",
 }
 nb_execution_mode = "cache"
+nb_execution_timeout = -1
